Module array2dplot

Module array2dplot 

Structs

Array2dPlot
A structure representing a 2D array plot.
Array2dPlotBuilder
Use builder syntax to set the inputs and finish with build().
Array2dPlotTryBuilder
Use builder syntax to set the inputs and finish with try_build().