Module barplot

Module barplot 

Structs

BarPlot
A structure representing a bar plot.
BarPlotBuilder
Use builder syntax to set the inputs and finish with build().
BarPlotTryBuilder
Use builder syntax to set the inputs and finish with try_build().