Module boxplot

Module boxplot 

Structs

BoxPlot
A structure representing a box plot.
BoxPlotBuilder
Use builder syntax to set the inputs and finish with build().
BoxPlotTryBuilder
Use builder syntax to set the inputs and finish with try_build().