Module candlestick

Module candlestick 

Structs

CandlestickPlot
A structure representing a Candlestick financial chart.
CandlestickPlotBuilder
Use builder syntax to set the inputs and finish with build().
CandlestickPlotTryBuilder
Use builder syntax to set the inputs and finish with try_build().