Module contourplot

Module contourplot 

Structs

ContourPlot
A structure representing a contour plot.
ContourPlotBuilder
Use builder syntax to set the inputs and finish with build().
ContourPlotTryBuilder
Use builder syntax to set the inputs and finish with try_build().