Module heatmap

Module heatmap 

Structs

HeatMap
A structure representing a heat map.
HeatMapBuilder
Use builder syntax to set the inputs and finish with build().
HeatMapTryBuilder
Use builder syntax to set the inputs and finish with try_build().