Module histogram

Module histogram 

Structs

Histogram
A structure representing a histogram.
HistogramBuilder
Use builder syntax to set the inputs and finish with build().
HistogramTryBuilder
Use builder syntax to set the inputs and finish with try_build().