Module image

Module image 

Structs

Image
A structure representing an image plot.
ImageBuilder
Use builder syntax to set the inputs and finish with build().
ImageTryBuilder
Use builder syntax to set the inputs and finish with try_build().