Module lineplot

Module lineplot 

Structs

LinePlot
A structure representing a line plot.
LinePlotBuilder
Use builder syntax to set the inputs and finish with build().
LinePlotTryBuilder
Use builder syntax to set the inputs and finish with try_build().