Module mesh3d

Module mesh3d 

Structs

Mesh3D
A structure representing a 3D mesh plot.
Mesh3DBuilder
Use builder syntax to set the inputs and finish with build().
Mesh3DTryBuilder
Use builder syntax to set the inputs and finish with try_build().