Module ohlc

Module ohlc 

Structs

OhlcPlot
A structure representing an OHLC (Open-High-Low-Close) financial chart.
OhlcPlotBuilder
Use builder syntax to set the inputs and finish with build().
OhlcPlotTryBuilder
Use builder syntax to set the inputs and finish with try_build().