Module piechart

Module piechart 

Structs

PieChart
A structure representing a pie chart.
PieChartBuilder
Use builder syntax to set the inputs and finish with build().
PieChartTryBuilder
Use builder syntax to set the inputs and finish with try_build().