Structs
- Sankey
Diagram - A structure representing a Sankey diagram.
- Sankey
Diagram Builder - Use builder syntax to set the inputs and finish with
build(). - Sankey
Diagram TryBuilder - Use builder syntax to set the inputs and finish with
try_build().
build().try_build().