Module scatter3dplot

Module scatter3dplot 

Structs

Scatter3dPlot
A structure representing a 3D scatter plot.
Scatter3dPlotBuilder
Use builder syntax to set the inputs and finish with build().
Scatter3dPlotTryBuilder
Use builder syntax to set the inputs and finish with try_build().