Module scattergeo

Module scattergeo 

Structs

ScatterGeo
A structure representing a geographic scatter plot.
ScatterGeoBuilder
Use builder syntax to set the inputs and finish with build().
ScatterGeoTryBuilder
Use builder syntax to set the inputs and finish with try_build().