Module scattermap

Module scattermap 

Structs

ScatterMap
A structure representing a scatter plot on a map.
ScatterMapBuilder
Use builder syntax to set the inputs and finish with build().
ScatterMapTryBuilder
Use builder syntax to set the inputs and finish with try_build().