Module scatterplot

Module scatterplot 

Structs

ScatterPlot
A structure representing a scatter plot.
ScatterPlotBuilder
Use builder syntax to set the inputs and finish with build().
ScatterPlotTryBuilder
Use builder syntax to set the inputs and finish with try_build().