Module scatterpolar

Module scatterpolar 

Structs

ScatterPolar
A structure representing a scatter polar plot.
ScatterPolarBuilder
Use builder syntax to set the inputs and finish with build().
ScatterPolarTryBuilder
Use builder syntax to set the inputs and finish with try_build().