Module surfaceplot

Module surfaceplot 

Structs

SurfacePlot
A structure representing a 3-D surface plot.
SurfacePlotBuilder
Use builder syntax to set the inputs and finish with build().
SurfacePlotTryBuilder
Use builder syntax to set the inputs and finish with try_build().