Module table

Module table 

Structs

Table
A structure representing a table plot.
TableBuilder
Use builder syntax to set the inputs and finish with build().
TableTryBuilder
Use builder syntax to set the inputs and finish with try_build().