Module timeseriesplot

Module timeseriesplot 

Structs

TimeSeriesPlot
A structure representing a time series plot.
TimeSeriesPlotBuilder
Use builder syntax to set the inputs and finish with build().
TimeSeriesPlotTryBuilder
Use builder syntax to set the inputs and finish with try_build().