Structs
- Array2d
Plot - A structure representing a 2D array plot.
- Array2d
Plot Builder - Use builder syntax to set the inputs and finish with
build(). - Array2d
Plot TryBuilder - Use builder syntax to set the inputs and finish with
try_build().
build().try_build().