Module barplot
plotlars_
core
0.12.1
Module barplot
Module Items
Structs
In plotlars_
core::
plots
plotlars_core
::
plots
Module
barplot
Structs

BarPlot
A structure representing a bar plot.
BarPlot
Builder
Use builder syntax to set the inputs and finish with
build()
.
BarPlot
TryBuilder
Use builder syntax to set the inputs and finish with
try_build()
.