Module boxplot
plotlars_
core
0.12.1
Module boxplot
Module Items
Structs
In plotlars_
core::
plots
plotlars_core
::
plots
Module
boxplot
Structs

BoxPlot
A structure representing a box plot.
BoxPlot
Builder
Use builder syntax to set the inputs and finish with
build()
.
BoxPlot
TryBuilder
Use builder syntax to set the inputs and finish with
try_build()
.