Structs
- Contour
Plot - A structure representing a contour plot.
- Contour
Plot Builder - Use builder syntax to set the inputs and finish with
build(). - Contour
Plot TryBuilder - Use builder syntax to set the inputs and finish with
try_build().
build().try_build().