Structs
- Histogram
- A structure representing a histogram.
- Histogram
Builder - Use builder syntax to set the inputs and finish with
build(). - Histogram
TryBuilder - Use builder syntax to set the inputs and finish with
try_build().
build().try_build().