Structs
- Line
Plot - A structure representing a line plot.
- Line
Plot Builder - Use builder syntax to set the inputs and finish with
build(). - Line
Plot TryBuilder - Use builder syntax to set the inputs and finish with
try_build().
build().try_build().