Module mesh3d
plotlars_
core
0.12.1
Module mesh3d
Module Items
Structs
In plotlars_
core::
plots
plotlars_core
::
plots
Module
mesh3d
Structs

Mesh3D
A structure representing a 3D mesh plot.
Mesh3D
Builder
Use builder syntax to set the inputs and finish with
build()
.
Mesh3D
TryBuilder
Use builder syntax to set the inputs and finish with
try_build()
.