Structs
- Ohlc
Plot - A structure representing an OHLC (Open-High-Low-Close) financial chart.
- Ohlc
Plot Builder - Use builder syntax to set the inputs and finish with
build(). - Ohlc
Plot TryBuilder - Use builder syntax to set the inputs and finish with
try_build().