Structs
- Scatter3d
Plot - A structure representing a 3D scatter plot.
- Scatter3d
Plot Builder - Use builder syntax to set the inputs and finish with
build(). - Scatter3d
Plot TryBuilder - Use builder syntax to set the inputs and finish with
try_build().
build().try_build().