Structs
- Scatter
Geo - A structure representing a geographic scatter plot.
- Scatter
GeoBuilder - Use builder syntax to set the inputs and finish with
build(). - Scatter
GeoTry Builder - Use builder syntax to set the inputs and finish with
try_build().
build().try_build().