Structs
- Scatter
Map - A structure representing a scatter plot on a map.
- Scatter
MapBuilder - Use builder syntax to set the inputs and finish with
build(). - Scatter
MapTry Builder - Use builder syntax to set the inputs and finish with
try_build().
build().try_build().