Structs
- Scatter
Plot - A structure representing a scatter plot.
- Scatter
Plot Builder - Use builder syntax to set the inputs and finish with
build(). - Scatter
Plot TryBuilder - Use builder syntax to set the inputs and finish with
try_build().
build().try_build().