Structs
- Surface
Plot - A structure representing a 3-D surface plot.
- Surface
Plot Builder - Use builder syntax to set the inputs and finish with
build(). - Surface
Plot TryBuilder - Use builder syntax to set the inputs and finish with
try_build().
build().try_build().