Structs
- Time
Series Plot - A structure representing a time series plot.
- Time
Series Plot Builder - Use builder syntax to set the inputs and finish with
build(). - Time
Series Plot TryBuilder - Use builder syntax to set the inputs and finish with
try_build().